@@ -1,13 +1,14 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to interact with AWS AppMesh API
 """
 
+from compose_x_common.compose_x_common import keyisset
+
 from ecs_composex.appmesh.appmesh_params import MESH_NAME, MESH_OWNER_ID
-from ecs_composex.common import LOG, keyisset
+from ecs_composex.common import LOG
 
 
 def find_mesh_in_list(mesh_name, client, next_token=None):
